import re
from dns import resolver
import socket
import smtplib


class EmailExistence:
    """
    Checks email for existence
    email - email for verification
    server_mail - email for make request
    
    """
    def __init__(self, email, server_mail='me@domain.com'):
        self.email = email
        self.server_mail = server_mail
        self.code = None
        self.message = None
        self.__check_email()

    def __check_email(self):
        match = re.match(
            '^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,4})$',
            self.email)
        if match is None:
            self.message = 'Bad Syntax'
        else:
            try:
                domain_name = self.email.split('@')[1]
                records = resolver.query(domain_name, 'MX')
                mx_record = records[0].exchange
                mx_record = str(mx_record)
                host = socket.gethostname()
                server = smtplib.SMTP()
                server.set_debuglevel(0)
                server.connect(mx_record)
                server.helo(host)
                server.mail(self.server_mail)
                self.code, self.message = server.rcpt(str(self.email))
                server.quit()
            except Exception as e:
                self.message = e
